=======
Credits
=======

Development Lead
----------------

* Fantix King <fantix.king@gmail.com>

Maintainers
-----------

* Tony Wang <wwwjfy@gmail.com>

Contributors
------------

* Neal Wang <qdzzyb2015@gamil.com>
* Binghan Li <lbhsot@163.com>
* Vladimir Goncharov <dev.zelta@gmail.com>
* Kinware <oss@kinware.com>
* Kentoseth <kentoseth@devcroo.com>
* Ádám Barancsuk <adam.barancsuk@gmail.com>
* Sergey Kovalev <s_kovalev@wargaming.net>
* jonahfang
* Yurii Shtrikker <nbb.unitto@gmail.com>
* Nicolas Crocfer <ncrocfer@gmail.com>
* Denys Badzo <badzyo360@gmail.com>
* Pavol Vargovcik <pavol.vargovcik@gmail.com>
* Mykyta Holubakha <hilobakho@gmail.com>
* Jekel <jekel@psyspace.ru>
* Martin Zaťko <martin.zatko@kiwi.com>
* Pascal van Kooten <kootenpv@gmail.com>


Special thanks to my wife Daisy and her outsourcing company `DecentFoX Studio`_,
for offering me the opportunity to build this project. We are open for global
software project outsourcing on Python, iOS and Android development.

.. _DecentFoX Studio: https://decentfox.com/
